@@ -200,7 +200,7 @@ p <- st_sample(x, 10)
 x = st_sfc(st_polygon(list(rbind(c(-180,-90),c(180,-90),c(180,90),c(-180,90),c(-180,-90)))),
  crs=st_crs(4326))
 #FIXME:
-# if (sf_extSoftVersion()["proj.4"] >= "4.9.0") # lwgeom breaks on this
+# if (sf_extSoftVersion()[["proj.4"]] >= "4.9.0") # lwgeom breaks on this
 #   (p <- st_sample(x, 10))
 pt = st_multipoint(matrix(1:20,,2))
 st_sample(p, 3)
@@ -241,7 +241,7 @@ plot(st_jitter(st_geometry(nc), factor = .01), add = TRUE, col = '#ff8888')
 st_jitter(st_sfc(st_point(0:1)), amount = .1)
 
 # st_bbox:
-if (require(sp, quietly = TRUE) && require(raster, quietly = TRUE)) {
+if (suppressPackageStartupMessages(require(sp, quietly = TRUE)) && require(raster, quietly = TRUE)) {
 demo(meuse, ask = FALSE, echo = FALSE)
 suppressWarnings(st_bbox(meuse))
 crs = suppressWarnings(st_crs(meuse))
